################################################################
# vs.dashboardmanager
# (C) 2010, Veit Schiele & Andreas Jung
# Published under the GNU Public Licence V 2 (GPL 2)
################################################################

from plone.app.portlets.interfaces import IColumn
from plone.portlets.interfaces import IPortletManager

class IPortletPageColumn(IColumn):
    """Marker interface describing columns on a portlet page
    """

class IPortletPageColumn1(IPortletManager):
    """ Portlet manager for vs.dashboardmanager """

class IPortletPageColumn2(IPortletManager):
    """ Portlet manager for vs.dashboardmanager """

class IPortletPageColumn3(IPortletManager):
    """ Portlet manager for vs.dashboardmanager """

class IPortletPageColumn4(IPortletManager):
    """ Portlet manager for vs.dashboardmanager """
