################################################################
# vs.dashboardmanager
# (C) 2010, Veit Schiele & Andreas Jung
# Published under the GNU Public Licence V 2 (GPL 2)
################################################################


import patches
from zope.i18nmessageid import MessageFactory

MF = MessageFactory('vs.dashboardmanager')

def initialize(context):
    """Initializer called when used as a Zope 2 product."""

